@@ -3,7 +3,7 @@
  *
  *	This file contains code to manage the interpreter result.
  *
- * Copyright (c) 1997 by Sun Microsystems, Inc.
+ * Copyright (c) 1997 Sun Microsystems, Inc.
  *
  * See the file "license.terms" for information on usage and redistribution of
  * this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -54,10 +54,10 @@ typedef struct InterpState {
  * Tcl_SaveInterpState --
  *
  *	Fills a token with a snapshot of the current state of the interpreter.
- *	The snapshot can be restored at any point by TclRestoreInterpState.
+ *	The snapshot can be restored at any point by Tcl_RestoreInterpState.
  *
- *	The token returned must be eventally passed to one of the routines
- *	TclRestoreInterpState or TclDiscardInterpState, or there will be a
+ *	The token returned must be eventually passed to one of the routines
+ *	Tcl_RestoreInterpState or Tcl_DiscardInterpState, or there will be a
  *	memory leak.
  *
  * Results:
@@ -75,7 +75,7 @@ Tcl_SaveInterpState(
     int status)			/* status code for current operation */
 {
     Interp *iPtr = (Interp *) interp;
-    InterpState *statePtr = ckalloc(sizeof(InterpState));
+    InterpState *statePtr = (InterpState *)ckalloc(sizeof(InterpState));
 
     statePtr->status = status;
     statePtr->flags = iPtr->flags & ERR_ALREADY_LOGGED;
@@ -245,7 +245,7 @@ Tcl_SaveResult(
      */
 
     statePtr->objResultPtr = iPtr->objResultPtr;
-    iPtr->objResultPtr = Tcl_NewObj();
+    TclNewObj(iPtr->objResultPtr);
     Tcl_IncrRefCount(iPtr->objResultPtr);
 
     /*
@@ -384,9 +384,9 @@ Tcl_DiscardResult(
     if (statePtr->result == statePtr->appendResult) {
 	ckfree(statePtr->appendResult);
     } else if (statePtr->freeProc == TCL_DYNAMIC) {
-        ckfree(statePtr->result);
+	ckfree(statePtr->result);
     } else if (statePtr->freeProc) {
-        statePtr->freeProc(statePtr->result);
+	statePtr->freeProc(statePtr->result);
     }
 }
 
@@ -491,7 +491,7 @@ Tcl_GetStringResult(
     Interp *iPtr = (Interp *) interp;
 
     if (*(iPtr->result) == 0) {
-	Tcl_SetResult(interp, TclGetString(Tcl_GetObjResult(interp)),
+	Tcl_SetResult(interp, Tcl_GetString(Tcl_GetObjResult(interp)),
 		TCL_VOLATILE);
     }
     return iPtr->result;
@@ -917,7 +917,7 @@ Tcl_FreeResult(
 
 void
 Tcl_ResetResult(
-    Tcl_Interp *interp)/* Interpreter for which to clear result. */
+    Tcl_Interp *interp)		/* Interpreter for which to clear result. */
 {
     Interp *iPtr = (Interp *) interp;
 
@@ -980,7 +980,7 @@ Tcl_ResetResult(
 
 static void
 ResetObjResult(
-    Interp *iPtr)	/* Points to the interpreter whose result
+    Interp *iPtr)		/* Points to the interpreter whose result
 				 * object should be reset. */
 {
     Tcl_Obj *objResultPtr = iPtr->objResultPtr;
@@ -1026,7 +1026,9 @@ Tcl_SetErrorCodeVA(
     Tcl_Interp *interp,		/* Interpreter in which to set errorCode */
     va_list argList)		/* Variable argument list. */
 {
-    Tcl_Obj *errorObj = Tcl_NewObj();
+    Tcl_Obj *errorObj;
+
+    TclNewObj(errorObj);
 
     /*
      * Scan through the arguments one at a time, appending them to the
@@ -1173,8 +1175,8 @@ static Tcl_Obj **
 GetKeys(void)
 {
     static Tcl_ThreadDataKey returnKeysKey;
-    Tcl_Obj **keys = Tcl_GetThreadData(&returnKeysKey,
-	    (int) (KEY_LAST * sizeof(Tcl_Obj *)));
+    Tcl_Obj **keys = (Tcl_Obj **)Tcl_GetThreadData(&returnKeysKey,
+	    KEY_LAST * sizeof(Tcl_Obj *));
 
     if (keys[0] == NULL) {
 	/*
@@ -1225,7 +1227,7 @@ static void
 ReleaseKeys(
     ClientData clientData)
 {
-    Tcl_Obj **keys = clientData;
+    Tcl_Obj **keys = (Tcl_Obj **)clientData;
     int i;
 
     for (i = KEY_CODE; i < KEY_LAST; i++) {
@@ -1283,61 +1285,61 @@ TclProcessReturn(
 	    iPtr->errorInfo = NULL;
 	}
 	Tcl_DictObjGet(NULL, iPtr->returnOpts, keys[KEY_ERRORINFO],
-                &valuePtr);
+		&valuePtr);
 	if (valuePtr != NULL) {
-	    int infoLen;
+	    int length;
 
-	    (void) TclGetStringFromObj(valuePtr, &infoLen);
-	    if (infoLen) {
+	    (void)TclGetStringFromObj(valuePtr, &length);
+	    if (length) {
 		iPtr->errorInfo = valuePtr;
 		Tcl_IncrRefCount(iPtr->errorInfo);
 		iPtr->flags |= ERR_ALREADY_LOGGED;
 	    }
 	}
 	Tcl_DictObjGet(NULL, iPtr->returnOpts, keys[KEY_ERRORSTACK],
-                &valuePtr);
+		&valuePtr);
 	if (valuePtr != NULL) {
-            int len, valueObjc;
-            Tcl_Obj **valueObjv;
+	    int len, valueObjc;
+	    Tcl_Obj **valueObjv;
 
-            if (Tcl_IsShared(iPtr->errorStack)) {
-                Tcl_Obj *newObj;
+	    if (Tcl_IsShared(iPtr->errorStack)) {
+		Tcl_Obj *newObj;
 
-                newObj = Tcl_DuplicateObj(iPtr->errorStack);
-                Tcl_DecrRefCount(iPtr->errorStack);
-                Tcl_IncrRefCount(newObj);
-                iPtr->errorStack = newObj;
-            }
+		newObj = Tcl_DuplicateObj(iPtr->errorStack);
+		Tcl_DecrRefCount(iPtr->errorStack);
+		Tcl_IncrRefCount(newObj);
+		iPtr->errorStack = newObj;
+	    }
 
-            /*
-             * List extraction done after duplication to avoid moving the rug
-             * if someone does [return -errorstack [info errorstack]]
-             */
+	    /*
+	     * List extraction done after duplication to avoid moving the rug
+	     * if someone does [return -errorstack [info errorstack]]
+	     */
 
-            if (Tcl_ListObjGetElements(interp, valuePtr, &valueObjc,
-                    &valueObjv) == TCL_ERROR) {
-                return TCL_ERROR;
-            }
-            iPtr->resetErrorStack = 0;
-            Tcl_ListObjLength(interp, iPtr->errorStack, &len);
+	    if (TclListObjGetElements(interp, valuePtr, &valueObjc,
+		    &valueObjv) == TCL_ERROR) {
+		return TCL_ERROR;
+	    }
+	    iPtr->resetErrorStack = 0;
+	    TclListObjLength(interp, iPtr->errorStack, &len);
 
-            /*
-             * Reset while keeping the list internalrep as much as possible.
-             */
+	    /*
+	     * Reset while keeping the list internalrep as much as possible.
+	     */
 
-            Tcl_ListObjReplace(interp, iPtr->errorStack, 0, len, valueObjc,
-                    valueObjv);
- 	}
+	    Tcl_ListObjReplace(interp, iPtr->errorStack, 0, len, valueObjc,
+		    valueObjv);
+	}
 	Tcl_DictObjGet(NULL, iPtr->returnOpts, keys[KEY_ERRORCODE],
-                &valuePtr);
+		&valuePtr);
 	if (valuePtr != NULL) {
 	    Tcl_SetObjErrorCode(interp, valuePtr);
 	} else {
-	    Tcl_SetErrorCode(interp, "NONE", NULL);
+	    Tcl_SetErrorCode(interp, "NONE", (char *)NULL);
 	}
 
 	Tcl_DictObjGet(NULL, iPtr->returnOpts, keys[KEY_ERRORLINE],
-                &valuePtr);
+		&valuePtr);
 	if (valuePtr != NULL) {
 	    TclGetIntFromObj(NULL, valuePtr, &iPtr->errorLine);
 	}
@@ -1387,13 +1389,13 @@ TclMergeReturnOptions(
     int code = TCL_OK;
     int level = 1;
     Tcl_Obj *valuePtr;
-    Tcl_Obj *returnOpts = Tcl_NewObj();
+    Tcl_Obj *returnOpts;
     Tcl_Obj **keys = GetKeys();
 
+    TclNewObj(returnOpts);
     for (;  objc > 1;  objv += 2, objc -= 2) {
-	int optLen;
+	int optLen, compareLen;
 	const char *opt = TclGetStringFromObj(objv[0], &optLen);
-	int compareLen;
 	const char *compare =
 		TclGetStringFromObj(keys[KEY_OPTIONS], &compareLen);
 
@@ -1411,10 +1413,10 @@ TclMergeReturnOptions(
 		 */
 
 		Tcl_SetObjResult(interp, Tcl_ObjPrintf(
-                        "bad %s value: expected dictionary but got \"%s\"",
-                        compare, TclGetString(objv[1])));
+			"bad %s value: expected dictionary but got \"%s\"",
+			compare, TclGetString(objv[1])));
 		Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_OPTIONS",
-			NULL);
+			(char *)NULL);
 		goto error;
 	    }
 
@@ -1442,7 +1444,7 @@ TclMergeReturnOptions(
     Tcl_DictObjGet(NULL, returnOpts, keys[KEY_CODE], &valuePtr);
     if (valuePtr != NULL) {
 	if (TclGetCompletionCodeFromObj(interp, valuePtr,
-                &code) == TCL_ERROR) {
+		&code) == TCL_ERROR) {
 	    goto error;
 	}
 	Tcl_DictObjRemove(NULL, returnOpts, keys[KEY_CODE]);
@@ -1461,9 +1463,9 @@ TclMergeReturnOptions(
 	     */
 
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
-                    "bad -level value: expected non-negative integer but got"
-                    " \"%s\"", TclGetString(valuePtr)));
-	    Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_LEVEL", NULL);
+		    "bad -level value: expected non-negative integer but got"
+		    " \"%s\"", TclGetString(valuePtr)));
+	    Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_LEVEL", (char *)NULL);
 	    goto error;
 	}
 	Tcl_DictObjRemove(NULL, returnOpts, keys[KEY_LEVEL]);
@@ -1477,16 +1479,16 @@ TclMergeReturnOptions(
     if (valuePtr != NULL) {
 	int length;
 
-	if (TCL_ERROR == Tcl_ListObjLength(NULL, valuePtr, &length )) {
+	if (TCL_ERROR == TclListObjLength(NULL, valuePtr, &length )) {
 	    /*
 	     * Value is not a list, which is illegal for -errorcode.
 	     */
 
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
-                    "bad -errorcode value: expected a list but got \"%s\"",
-                    TclGetString(valuePtr)));
+		    "bad -errorcode value: expected a list but got \"%s\"",
+		    TclGetString(valuePtr)));
 	    Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_ERRORCODE",
-		    NULL);
+		    (char *)NULL);
 	    goto error;
 	}
     }
@@ -1499,30 +1501,30 @@ TclMergeReturnOptions(
     if (valuePtr != NULL) {
 	int length;
 
-	if (TCL_ERROR == Tcl_ListObjLength(NULL, valuePtr, &length )) {
+	if (TCL_ERROR == TclListObjLength(NULL, valuePtr, &length)) {
 	    /*
 	     * Value is not a list, which is illegal for -errorstack.
 	     */
 
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
-                    "bad -errorstack value: expected a list but got \"%s\"",
-                    TclGetString(valuePtr)));
+		    "bad -errorstack value: expected a list but got \"%s\"",
+		    TclGetString(valuePtr)));
 	    Tcl_SetErrorCode(interp, "TCL", "RESULT", "NONLIST_ERRORSTACK",
-                    NULL);
+		    (char *)NULL);
 	    goto error;
 	}
-        if (length % 2) {
-            /*
-             * Errorstack must always be an even-sized list
-             */
+	if (length % 2) {
+	    /*
+	     * Errorstack must always be an even-sized list
+	     */
 
 	    Tcl_SetObjResult(interp, Tcl_ObjPrintf(
-                    "forbidden odd-sized list for -errorstack: \"%s\"",
+		    "forbidden odd-sized list for -errorstack: \"%s\"",
 		    TclGetString(valuePtr)));
 	    Tcl_SetErrorCode(interp, "TCL", "RESULT",
-                    "ODDSIZEDLIST_ERRORSTACK", NULL);
+		    "ODDSIZEDLIST_ERRORSTACK", (char *)NULL);
 	    goto error;
-        }
+	}
     }
 
     /*
@@ -1585,7 +1587,7 @@ Tcl_GetReturnOptions(
     if (iPtr->returnOpts) {
 	options = Tcl_DuplicateObj(iPtr->returnOpts);
     } else {
-	options = Tcl_NewObj();
+	TclNewObj(options);
     }
 
     if (result == TCL_RETURN) {
@@ -1602,7 +1604,7 @@ Tcl_GetReturnOptions(
 
     if (result == TCL_ERROR) {
 	Tcl_AddErrorInfo(interp, "");
-        Tcl_DictObjPut(NULL, options, keys[KEY_ERRORSTACK], iPtr->errorStack);
+	Tcl_DictObjPut(NULL, options, keys[KEY_ERRORSTACK], iPtr->errorStack);
     }
     if (iPtr->errorCode) {
 	Tcl_DictObjPut(NULL, options, keys[KEY_ERRORCODE], iPtr->errorCode);
@@ -1665,15 +1667,16 @@ Tcl_SetReturnOptions(
     Tcl_Interp *interp,
     Tcl_Obj *options)
 {
-    int objc, level, code;
+    int objc;
+    int level, code;
     Tcl_Obj **objv, *mergedOpts;
 
     Tcl_IncrRefCount(options);
     if (TCL_ERROR == TclListObjGetElements(interp, options, &objc, &objv)
 	    || (objc % 2)) {
 	Tcl_SetObjResult(interp, Tcl_ObjPrintf(
-                "expected dict but got \"%s\"", TclGetString(options)));
-	Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_OPTIONS", NULL);
+		"expected dict but got \"%s\"", TclGetString(options)));
+	Tcl_SetErrorCode(interp, "TCL", "RESULT", "ILLEGAL_OPTIONS", (char *)NULL);
 	code = TCL_ERROR;
     } else if (TCL_ERROR == TclMergeReturnOptions(interp, objc, objv,
 	    &mergedOpts, &code, &level)) {
