@@ -35,7 +35,6 @@ static Tcl_ObjCmdProc	TesteventloopCmd;
 static Tcl_ObjCmdProc	TestvolumetypeCmd;
 static Tcl_ObjCmdProc	TestwinclockCmd;
 static Tcl_ObjCmdProc	TestwinsleepCmd;
-static Tcl_ObjCmdProc	TestSizeCmd;
 static Tcl_ObjCmdProc	TestExceptionCmd;
 static int		TestplatformChmod(const char *nativePath, int pmode);
 static Tcl_ObjCmdProc	TestchmodCmd;
@@ -72,7 +71,6 @@ TclplatformtestInit(
     Tcl_CreateObjCommand(interp, "testwinclock", TestwinclockCmd, NULL, NULL);
     Tcl_CreateObjCommand(interp, "testwinsleep", TestwinsleepCmd, NULL, NULL);
     Tcl_CreateObjCommand(interp, "testexcept", TestExceptionCmd, NULL, NULL);
-    Tcl_CreateObjCommand(interp, "testsize", TestSizeCmd, NULL, NULL);
     return TCL_OK;
 }
 
@@ -307,27 +305,6 @@ TestwinsleepCmd(
     return TCL_OK;
 }
 
-static int
-TestSizeCmd(
-    ClientData clientData,	/* Unused */
-    Tcl_Interp* interp,		/* Tcl interpreter */
-    int objc,			/* Parameter count */
-    Tcl_Obj *const * objv)	/* Parameter vector */
-{
-    if (objc != 2) {
-	goto syntax;
-    }
-    if (strcmp(Tcl_GetString(objv[1]), "st_mtime") == 0) {
-	Tcl_StatBuf *statPtr;
-	Tcl_SetObjResult(interp, Tcl_NewWideIntObj(sizeof(statPtr->st_mtime)));
-	return TCL_OK;
-    }
-
-syntax:
-    Tcl_WrongNumArgs(interp, 1, objv, "st_mtime");
-    return TCL_ERROR;
-}
-
 /*
  *----------------------------------------------------------------------
  *
